@@ -129,20 +129,12 @@ ContactsModel::convert (const ContactInfo &cInfo, GVContactInfo &gvcInfo)
     return (true);
 }//ContactsModel::convert
 
-bool
-ContactsModel::hasChildren (const QModelIndex &parent /*= QModelIndex()*/)
+void
+ContactsModel::clearAll ()
 {
-    bool rv = false;
-    QVariant var = this->data (parent, CT_ContactsRole);
-    if (var.isValid ()) {
-        // Delete the contents of the var
-        ContactDetailsModel *pCdm = (ContactDetailsModel *)
-                                    var.value <QObject *>();
-        if (NULL != pCdm) {
-            delete pCdm;
-        }
-        rv = true;
-    }
+    CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
 
-    return (rv);
-}//ContactsModel::hasChildren
+    beginRemoveRows (QModelIndex (), 0, this->rowCount ());
+    dbMain.clearContacts ();
+    endRemoveRows ();
+}//ContactsModel::clearAll
