@@ -70,15 +70,10 @@ public:
     static bool isNumberValid (const QString &strNumber);
     static void beautify_number (QString &strNumber);
 
-
-#if !NO_DBGINFO
     virtual void setView (QWidget *view);
-#endif
 
 signals:
-    //! Log emitter
-    void log(const QString &strText, int level = 10);
-    //! Log emitter
+    //! Status emitter
     void status(const QString &strText, int timeout = 2000);
 
     //! When we start loading a page
